==> hussar-skins-1.6.6.jar: static/assets/lib/layui2.4.5/layui.extend.js <==
/**
 * 权限平台公共方法封装
 * 2018.3.16
 * sunZengXin
 */
layui.config({
	  base: hussar_path +'/static/'
	  ,version: '101100'
	}).extend({ //设定模块别名
			Hussar: 'js/common/Hussar' //公共方法：错误提示，提醒，打开页面等方法
			,jstree:'assets/lib/jsTree/jstree' //引入jstree
			,HussarAjax:'js/common/HussarAjax' //HussarAjax
			,HussarSecurity:'js/common/HussarSecurity' //HussarAjax
			,multiselect:'assets/lib/multiselect/multiselect'
			,bootstrap:'assets/lib/bootstrap/bootstrap'
    		,bootstrap_table:'assets/lib/bootstrap-table/bootstrap-table'
			,bootstrap_table_cn:'assets/lib/bootstrap-table/locale/bootstrap-table-zh-CN'
			,bootstrap_table_edit:'assets/lib/bootstrap-table-edit/bootstrap-table-edit'
			,bootstrap_editable:'assets/lib/bootstrap-table-edit/bootstrap-editable'
			,fontIconPicker:'assets/lib/fontIconPicker/jquery.fonticonpicker'//图标选择器
			,jqForm:'bpm/jquery/jquery-form'
	        ,HussarBpm:'bpm/common/HussarBpm'
			,jqueryui:'assets/lib/jquery-ui/jquery-ui'
    		,bootstrap_table_resizable:'assets/lib/bootstrap-table-edit/bootstrap-table-resizable'
    		,colResizable:'assets/lib/bootstrap-table-edit/colResizable-1.6'
			,bootstrap_table_reorder_columns:'assets/lib/bootstrap-table-edit/bootstrap-table-reorder-columns'
    		,jquerydragtable:'assets/lib/bootstrap-table-edit/jquery.dragtable'
			,tableExport:'assets/lib/bootstrap-table-edit/tableExport'
    		,bootstrap_table_export:'assets/lib/bootstrap-table-edit/bootstrap-table-export'
   			,ueditorConfig:'assets/lib/ueditor/ueditor.config'
    		,ueditor:'assets/lib/ueditor/ueditor.all.min'
    		,autoHeight:'assets/lib/autoHeight/autoHeight'
			,multiSelect:'assets/lib/layui2.4.5/lay/modules/multiSelect' // 多选下拉框
			,cascadeSelect:'assets/lib/layui2.4.5/lay/modules/cascadeSelect' // 级联下拉框
			,sliderVerify:'assets/lib/sliderVerify/sliderVerify.min' // 滑块验证
			,ztree:'assets/lib/zTree/js/jquery.ztree.core' //ztree.core
			,ztree_excheck:'assets/lib/zTree/js/jquery.ztree.excheck' //单选，多选
			,ztree_exedit:'assets/lib/zTree/js/jquery.ztree.exedit' //节点编辑
			,ztree_exhide:'assets/lib/zTree/js/jquery.ztree.exhide' //其他扩展功能
	});

==> hussar-skins-1.7.0.jar: static/assets/lib/layui2.4.5/layui.extend.js <==
/**
 * 权限平台公共方法封装
 * 2018.3.16
 * sunZengXin
 */
layui.config({
	  base: hussar_path +'/static/'
	  ,version: '101100'
	}).extend({ //设定模块别名
			Hussar: 'js/common/Hussar' //公共方法：错误提示，提醒，打开页面等方法
			,jstree:'assets/lib/jsTree/jstree' //引入jstree
			,HussarAjax:'js/common/HussarAjax' //HussarAjax
			,HussarSecurity:'js/common/HussarSecurity' //登录密码加密
			,HussarEncrypt:'js/common/HussarEncrypt'//国密加密组件
			,multiselect:'assets/lib/multiselect/multiselect'
			,bootstrap:'assets/lib/bootstrap/bootstrap'
    		,bootstrap_table:'assets/lib/bootstrap-table/bootstrap-table'
			,bootstrap_table_cn:'assets/lib/bootstrap-table/locale/bootstrap-table-zh-CN'
			,bootstrap_table_edit:'assets/lib/bootstrap-table-edit/bootstrap-table-edit'
			,bootstrap_editable:'assets/lib/bootstrap-table-edit/bootstrap-editable'
			,fontIconPicker:'assets/lib/fontIconPicker/jquery.fonticonpicker'//图标选择器
			,jqForm:'bpm/jquery/jquery-form'
	        ,HussarBpm:'bpm/common/HussarBpm'
			,jqueryui:'assets/lib/jquery-ui/jquery-ui'
    		,bootstrap_table_resizable:'assets/lib/bootstrap-table-edit/bootstrap-table-resizable'
    		,colResizable:'assets/lib/bootstrap-table-edit/colResizable-1.6'
			,bootstrap_table_reorder_columns:'assets/lib/bootstrap-table-edit/bootstrap-table-reorder-columns'
    		,jquerydragtable:'assets/lib/bootstrap-table-edit/jquery.dragtable'
			,tableExport:'assets/lib/bootstrap-table-edit/tableExport'
    		,bootstrap_table_export:'assets/lib/bootstrap-table-edit/bootstrap-table-export'
   			,ueditorConfig:'assets/lib/ueditor/ueditor.config'
    		,ueditor:'assets/lib/ueditor/ueditor.all.min'
    		,autoHeight:'assets/lib/autoHeight/autoHeight'
			,multiSelect:'assets/lib/layui2.4.5/lay/modules/multiSelect' // 多选下拉框
			,cascadeSelect:'assets/lib/layui2.4.5/lay/modules/cascadeSelect' // 级联下拉框
			,sliderVerify:'assets/lib/sliderVerify/sliderVerify.min' // 滑块验证
			,ztree:'assets/lib/zTree/js/jquery.ztree.core' //ztree.core
			,ztree_excheck:'assets/lib/zTree/js/jquery.ztree.excheck' //单选，多选
			,ztree_exedit:'assets/lib/zTree/js/jquery.ztree.exedit' //节点编辑
			,ztree_exhide:'assets/lib/zTree/js/jquery.ztree.exhide' //其他扩展功能
	});
